@@ -1,6 +1,3 @@
-# Copyright (c) gocept gmbh & co. kg
-# See also LICENSE.txt
-
 """Controller logic for check execution.
 
 This module contains the :class:`Check` class which orchestrates the
@@ -20,7 +17,7 @@ from .metric import Metric
 from .resource import Resource
 from .result import Result, Results
 from .runtime import Runtime
-from .state import Ok, Unknown
+from .state import Ok, Unknown, ServiceState
 from .summary import Summary
 import logging
 
@@ -82,7 +79,15 @@ class Check(object):
             for metric in metrics:
                 context = self.contexts[metric.context]
                 metric = metric.replace(contextobj=context, resource=resource)
-                self.results.add(metric.evaluate())
+                result = metric.evaluate()
+                if isinstance(result, Result):
+                    self.results.add(result)
+                elif isinstance(result, ServiceState):
+                    self.results.add(Result(result, metric=metric))
+                else:
+                    raise ValueError(
+                        'evaluate() returned neither Result nor ServiceState '
+                        'object', metric.name, result)
                 self.perfdata.append(str(metric.performance() or ''))
         except CheckError as e:
             self.results.add(Result(Unknown, str(e), metric))
@@ -100,7 +105,7 @@ class Check(object):
             self._evaluate_resource(resource)
         self.perfdata = sorted([p for p in self.perfdata if p])
 
-    def main(self, verbose=1, timeout=10):
+    def main(self, verbose=None, timeout=None):
         """All-in-one control delegation to the runtime environment.
 
         Get a :class:`~nagiosplugin.runtime.Runtime` instance and
