@@ -17,23 +17,31 @@ access to it. Changes to the dict are not reflected in the file until
 context manager to get it opened and committed automatically.
 """
 
-from .compat import UserDict, open_encoded
+from .compat import UserDict, TemporaryFile
 from .platform import flock_exclusive
+import codecs
 import json
 import os
+import tempfile
 
 
 class Cookie(UserDict, object):
 
-    def __init__(self, path):
+    def __init__(self, statefile=None):
         """Creates a persistent dict to keep state.
 
         After creation, a cookie behaves like a normal dict.
 
-        :param path: file to save the dict in (state file)
+        :param statefile: file name to save the dict's contents
+
+        .. note:: If `statefile` is empty or None, the Cookie will be
+           oblivous, i.e., it will forget its contents on garbage
+           collection. This makes it possible to explicitely throw away
+           state between plugin runs (for example by a command line
+           argument).
         """
         super(Cookie, self).__init__()
-        self.path = path
+        self.path = statefile
         self.fobj = None
 
     def __enter__(self):
@@ -64,19 +72,29 @@ class Cookie(UserDict, object):
         plugins will not fail repeatedly when their state files get
         damaged.
 
+        :returns: Cookie object (self)
         :raises ValueError: if the state file is corrupted or does not
             deserialize into a dict
         """
-        self.fobj = open_encoded(self.path, 'a+', encoding='ascii')
+        self.fobj = self._create_fobj()
         flock_exclusive(self.fobj)
-        if not os.fstat(self.fobj.fileno()).st_size:
-            # file is empty
-            return
+        if os.fstat(self.fobj.fileno()).st_size:
+            try:
+                self.data = self._load()
+            except ValueError:
+                self.fobj.truncate(0)
+                raise
+        return self
+
+    def _create_fobj(self):
+        if not self.path:
+            return TemporaryFile('w+', encoding='ascii',
+                                 prefix='oblivious_cookie_')
+        # mode='a+' has problems with mixed R/W operation on Mac OS X
         try:
-            self.data = self._load()
-        except ValueError:
-            self.fobj.truncate(0)
-            raise
+            return codecs.open(self.path, 'r+', encoding='ascii')
+        except IOError:
+            return codecs.open(self.path, 'w+', encoding='ascii')
 
     def _load(self):
         self.fobj.seek(0)
@@ -95,7 +113,6 @@ class Cookie(UserDict, object):
         """
         if not self.fobj:
             return
-        self.data = {}
         self.fobj.close()
         self.fobj = None
 
@@ -109,7 +126,7 @@ class Cookie(UserDict, object):
         if not self.fobj:
             raise IOError('cannot commit closed cookie', self.path)
         self.fobj.seek(0)
-        self.fobj.truncate(0)
+        self.fobj.truncate()
         json.dump(self.data, self.fobj)
         self.fobj.write('\n')
         self.fobj.flush()
