@@ -1,8 +1,12 @@
-# Copyright (c) 2012 gocept gmbh & co. kg
+# Copyright (c) gocept gmbh & co. kg
 # See also LICENSE.txt
 
 from nagiosplugin.performance import Performance
-import unittest
+
+try:
+    import unittest2 as unittest
+except ImportError:  # pragma: no cover
+    import unittest
 
 
 class PerformanceTest(unittest.TestCase):
@@ -10,13 +14,13 @@ class PerformanceTest(unittest.TestCase):
     def test_normal_label(self):
         self.assertEqual('d=10', str(Performance('d', 10)))
 
-    def test_label_too_long(self):
-        with self.assertRaises(RuntimeError):
-            str(Performance('d' * 21, 10))
-
     def test_label_quoted(self):
         self.assertEqual("'d d'=10", str(Performance('d d', 10)))
 
     def test_label_must_not_contain_quotes(self):
         with self.assertRaises(RuntimeError):
             str(Performance("d'", 10))
+
+    def test_label_must_not_contain_equals(self):
+        with self.assertRaises(RuntimeError):
+            str(Performance("d=", 10))
